/**
  ******************************************************************************
  * @file    ys32t030_tsc.h
  * @author  YSPRING Application Team
  * @version V1.0.1
  * @date    2023.6.28
  * @brief   This file contains all the functions prototypes for the TSC firmware 
  *          library.
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __YS32T030_TSC_H
#define __YS32T030_TSC_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "ys32t030.h"
#include "system_ys32t030.h"

/** @addtogroup YS32T030_StdPeriph_Driver
  * @{
  */

/** @addtogroup TSC
  * @{
  */

/* Exported types ------------------------------------------------------------*/

/** 
  * @brief  TSC Init structures definition  
  */
typedef struct{
    uint32_t TSC_ScanMode;
    uint32_t TSC_ClkSrc;
    uint32_t TSC_T16Src;
    uint32_t TSC_TimeSlotSrc;
    uint32_t TSC_RefOSCFreq;
    uint32_t TSC_AutoScanModeTime;
    uint32_t TSC_AutoScanModeTimeDiv;
    uint32_t TSC_OSCHopSel;
    uint32_t TSC_OSCHopFreq;
    uint32_t TSC_TouchKey;
}TSC_InitTypeDef;

/* Exported constants --------------------------------------------------------*/

/** @defgroup TSC_ClkSrc_define 
  * @{
  */ 
#define  TSC_ClkSrc_HCLK      0x00
#define  TSC_ClkSrc_LSI       (TSC_TKCR1_TKCLKSEL)

#define  IS_TSC_CLK_SRC(CLK_SRC)      (((CLK_SRC) == TSC_ClkSrc_HCLK)  || \
                                       ((CLK_SRC) == TSC_ClkSrc_LSI))                                 
/**
  * @}
  */ 

/** @defgroup TSC_AutoScanModeTime_define 
 * @{
 */ 
#define  TSC_AutoScanModeTime_2n13      TSC_TKCR1_ASMTO_000  //2^13/fLSI 
#define  TSC_AutoScanModeTime_2n14      TSC_TKCR1_ASMTO_001  //2^14/fLSI 
#define  TSC_AutoScanModeTime_2n15      TSC_TKCR1_ASMTO_010  //2^15/fLSI 
#define  TSC_AutoScanModeTime_2n16      TSC_TKCR1_ASMTO_011  //2^16/fLSI 
#define  TSC_AutoScanModeTime_2n17      TSC_TKCR1_ASMTO_100  //2^17/fLSI 
#define  TSC_AutoScanModeTime_2n18      TSC_TKCR1_ASMTO_101  //2^18/fLSI 

#define  IS_TSC_AUTO_SCAN_MODE_TIME(MODE_TIME)   (((MODE_TIME) == TSC_AutoScanModeTime_2n13)  || \
                                                  ((MODE_TIME) == TSC_AutoScanModeTime_2n14)  || \
                                                  ((MODE_TIME) == TSC_AutoScanModeTime_2n15)  || \
                                                  ((MODE_TIME) == TSC_AutoScanModeTime_2n16)  || \
                                                  ((MODE_TIME) == TSC_AutoScanModeTime_2n17)  || \
                                                  ((MODE_TIME) == TSC_AutoScanModeTime_2n18))                                 
/**
  * @}
  */ 
  
/** @defgroup TSC_AutoScanModeTimeDiv_define 
 * @{
 */ 
#define  TSC_AutoScanModeTime_Div2      TSC_TKCR1_ASMP_2  // TSC_AutoScanModeTime/2 
#define  TSC_AutoScanModeTime_Div4      TSC_TKCR1_ASMP_4  // TSC_AutoScanModeTime/4 
#define  TSC_AutoScanModeTime_Div8      TSC_TKCR1_ASMP_8  // TSC_AutoScanModeTime/8 
#define  TSC_AutoScanModeTime_Div16     TSC_TKCR1_ASMP_16 // TSC_AutoScanModeTime/16 

#define  IS_TSC_AUTO_SCAN_MODE_TIME_DIV(MODE_TIME_DIV)   (((MODE_TIME_DIV) == TSC_AutoScanModeTime_Div2 )  || \
                                                          ((MODE_TIME_DIV) == TSC_AutoScanModeTime_Div4 )  || \
                                                          ((MODE_TIME_DIV) == TSC_AutoScanModeTime_Div8 )  || \
                                                          ((MODE_TIME_DIV) == TSC_AutoScanModeTime_Div16))                                 
/**
  * @}
  */ 

/** @defgroup TSC_T16Src_define 
 * @{
 */ 
#define  TSC_T16Src_Div16      TSC_TKCR1_TK16S_16  // fTKCLK/16  
#define  TSC_T16Src_Div32      TSC_TKCR1_TK16S_32  // fTKCLK/32  
#define  TSC_T16Src_Div64      TSC_TKCR1_TK16S_64  // fTKCLK/64  
#define  TSC_T16Src_Div128     TSC_TKCR1_TK16S_128 // fTKCLK/128 

#define  IS_TSC_T16_SRC(COUNT_CLK) (((COUNT_CLK) == TSC_T16Src_Div16 )  || \
                                    ((COUNT_CLK) == TSC_T16Src_Div32 )  || \
                                    ((COUNT_CLK) == TSC_T16Src_Div64 )  || \
                                    ((COUNT_CLK) == TSC_T16Src_Div128))                                 
/**
  * @}
  */ 
  
/** @defgroup TSC_RefOSCFreq_define 
 * @{
 */ 
#define  TSC_RefOSCFreq_3M       TSC_TKCR1_TKFS_3MHz   // 3MHz   
#define  TSC_RefOSCFreq_7M       TSC_TKCR1_TKFS_7MHz   // 7MHz   
#define  TSC_RefOSCFreq_11M      TSC_TKCR1_TKFS_11MHz  // 11MHz  

#define  IS_TSC_REF_OSC_FREQ(FREQ_SEL)  (((FREQ_SEL) == TSC_RefOSCFreq_3M )  || \
                                         ((FREQ_SEL) == TSC_RefOSCFreq_7M )  || \
                                         ((FREQ_SEL) == TSC_RefOSCFreq_11M ))                                 
/**
  * @}
  */ 
  
/** @defgroup TSC_ScanMode_define 
 * @{
 */ 
#define  TSC_ScanMode_Auto          TSC_TKCR1_TKMOD_00  // Auto                          
#define  TSC_ScanMode_Manual        TSC_TKCR1_TKMOD_01  // Manual                        
#define  TSC_ScanMode_PeriodicAuto  TSC_TKCR1_TKMOD_10  // Periodic automatic scan mode  

#define  IS_TSC_SCAN_MODE(MODE)  (((MODE) == TSC_ScanMode_Auto )    || \
                                  ((MODE) == TSC_ScanMode_Manual )  || \
                                  ((MODE) == TSC_ScanMode_PeriodicAuto ))                                 
/**
  * @}
  */ 
  
/** @defgroup TSC_TimeSlotSrc_define 
 * @{
 */ 
#define  TSC_TimeSlotSrc_RefOSC   TSC_TKCR2_TSS_00  // Reference oscillator clock  
#define  TSC_TimeSlotSrc_Div32    TSC_TKCR2_TSS_01  // fTKCLK/32                   
#define  TSC_TimeSlotSrc_Div64    TSC_TKCR2_TSS_10  // fTKCLK/64                   
#define  TSC_TimeSlotSrc_Div128   TSC_TKCR2_TSS_11  // fTKCLK/128                  

#define  IS_TSC_TIME_SLOT_SRC(SLOT_SRC)  (((SLOT_SRC) == TSC_TimeSlotSrc_RefOSC)  || \
                                          ((SLOT_SRC) == TSC_TimeSlotSrc_Div32 )  || \
                                          ((SLOT_SRC) == TSC_TimeSlotSrc_Div64 )  || \
                                          ((SLOT_SRC) == TSC_TimeSlotSrc_Div128))                                 
/**
  * @}
  */ 
  
/** @defgroup TSC_OSCHopSel_define 
 * @{
 */ 
#define  TSC_OSCHopSel_Sofe      0               // Sofe Hop                         
#define  TSC_OSCHopSel_Hardware  TSC_TKCR2_SOFC  // Hardware Hop                      

#define  IS_TSC_OSC_HOP_SEL(HOP_SEL)       (((HOP_SEL) == TSC_OSCHopSel_Sofe )  || \
                                            ((HOP_SEL) == TSC_OSCHopSel_Hardware ))                                 
/**
  * @}
  */ 
  
/** @defgroup TSC_OSCHopFreq_define 
 * @{
 */ 
#define  TSC_OSCHopFreq_3_215M   TSC_TKCR2_SOF_3_215  // 3.215M  
#define  TSC_OSCHopFreq_3_190M   TSC_TKCR2_SOF_3_190  // 3.190M  
#define  TSC_OSCHopFreq_3_168M   TSC_TKCR2_SOF_3_168  // 3.168M  
#define  TSC_OSCHopFreq_3_144M   TSC_TKCR2_SOF_3_144  // 3.144M
#define  TSC_OSCHopFreq_3_122M   TSC_TKCR2_SOF_3_122  // 3.122M  
#define  TSC_OSCHopFreq_3_100M   TSC_TKCR2_SOF_3_100  // 3.100M  
#define  TSC_OSCHopFreq_3_082M   TSC_TKCR2_SOF_3_082  // 3.082M  
#define  TSC_OSCHopFreq_3_060M   TSC_TKCR2_SOF_3_060  // 3.060M

#define  IS_TSC_OSC_HOP_FREQ(HOP_FREQ)  (((HOP_FREQ) == TSC_OSCHopFreq_3_215M)  || \
                                         ((HOP_FREQ) == TSC_OSCHopFreq_3_190M)  || \
                                         ((HOP_FREQ) == TSC_OSCHopFreq_3_168M)  || \
                                         ((HOP_FREQ) == TSC_OSCHopFreq_3_144M)  || \
                                         ((HOP_FREQ) == TSC_OSCHopFreq_3_122M)  || \
                                         ((HOP_FREQ) == TSC_OSCHopFreq_3_100M)  || \
                                         ((HOP_FREQ) == TSC_OSCHopFreq_3_082M)  || \
                                         ((HOP_FREQ) == TSC_OSCHopFreq_3_060M))                                 
/**
  * @}
  */ 
  
/** @defgroup TSC_Key_define 
 * @{
 */ 
#define  TSC_KEY0     (uint32_t)(1<<0 )  // K0
#define  TSC_KEY1     (uint32_t)(1<<1 )  // K1 
#define  TSC_KEY2     (uint32_t)(1<<2 )  // K2  
#define  TSC_KEY3     (uint32_t)(1<<3 )  // K3  
#define  TSC_KEY4     (uint32_t)(1<<4 )  // K4  
#define  TSC_KEY5     (uint32_t)(1<<5 )  // K5  
#define  TSC_KEY6     (uint32_t)(1<<6 )  // K6  
#define  TSC_KEY7     (uint32_t)(1<<7 )  // K7  
#define  TSC_KEY8     (uint32_t)(1<<8 )  // K8  
#define  TSC_KEY9     (uint32_t)(1<<9 )  // K9  
#define  TSC_KEY10    (uint32_t)(1<<10)  // K10  
#define  TSC_KEY11    (uint32_t)(1<<11)  // K11  
#define  TSC_KEY12    (uint32_t)(1<<12)  // K12  
#define  TSC_KEY13    (uint32_t)(1<<13)  // K13 
#define  TSC_KEY14    (uint32_t)(1<<14)  // K14 
#define  TSC_KEY15    (uint32_t)(1<<15)  // K15 
#define  TSC_KEY16    (uint32_t)(1<<16)  // K16 
#define  TSC_KEY17    (uint32_t)(1<<17)  // K17 
#define  TSC_KEY18    (uint32_t)(1<<18)  // K18 
#define  TSC_KEY19    (uint32_t)(1<<19)  // K19 
#define  TSC_KEY20    (uint32_t)(1<<20)  // K20
#define  TSC_KEY21    (uint32_t)(1<<21)  // K21 
#define  TSC_KEY22    (uint32_t)(1<<22)  // K22 
#define  TSC_KEY23    (uint32_t)(1<<23)  // K23 

#define  IS_TSC_KEY_BITS(KEY_BITS)  (((KEY_BITS) <= 0xFFFFFF))                                 
/**
  * @}
  */ 

/** @defgroup TSC_KeyThresholdConfig_define 
 * @{
 */ 
#define  TSC_UpperThreshold           ((uint16_t)0x0001)         
#define  TSC_LowerThreshold           ((uint16_t)0x0000)            

#define  IS_TSC_ThresholdsValue(VALUE)    (((VALUE) == TSC_UpperThreshold )  || \
                                           ((VALUE) == TSC_LowerThreshold)) 
/**
  * @}
  */ 

/** @defgroup TSC_OSC_define 
 * @{
 */ 
#define  TSC_OSC_REF           TSC_TKCR2_ROEN         
#define  TSC_OSC_KEY           TSC_TKCR2_KOEN            

#define  IS_TSC_OSC(VALUE)     (((VALUE) == TSC_OSC_REF )  || \
                                ((VALUE) == TSC_OSC_KEY)) 
/**
  * @}
  */ 
  
/** @defgroup TSC_RefCAP_Config_define 
 * @{
 */ 
#define  TSC_REF_CAP(REF_CAP)  (((REF_CAP) <= 0x3FF))                                 
/**
  * @}
  */ 

/** @defgroup TSC_SetTimeSlotCount_define 
 * @{
 */ 
#define  TSC_INTERVAL_VALUE(VALUE)  (((VALUE) <= 0xFF))                                 
/**
  * @}
  */ 

/** @defgroup TSC_Buffer_Addr_define 
 * @{
 */ 
#define  TSC_BUFFER_ADDR(ADDR)  (((uint32_t)ADDR) >= SRAM_BASE && ((uint32_t)ADDR) <= SRAM_END)                             
/**
  * @}
  */ 

/** @defgroup TSC_Buffer_Len_define 
 * @{
 */ 
#define  TSC_KEY_CHANNEL(CHANNEL)  (((CHANNEL) <= 16))                                 
/**
  * @}
  */ 

/** @defgroup TSC_IT_Config_define 
 * @{
 */
#define  TSC_IT_TimeSlot                   TSC_TKIER_TKRCOVE     //TimeSlot               
#define  TSC_IT_TimeSlot_WakeUp            TSC_TKIER_TKRCOVWUEN  //TimeSlot WakeUp        
#define  TSC_IT_ThresholdMatches           TSC_TKIER_TKTHE       //Threshold Matches       
#define  TSC_IT_ThresholdMatches_WakeUp    TSC_TKIER_TKTHWUEN    //Threshold Matches WakeUp         

#define  IS_TSC_IT_CONFIG(IT_CONFIG)  (((IT_CONFIG) == TSC_IT_TimeSlot               )  || \
                                       ((IT_CONFIG) == TSC_IT_TimeSlot_WakeUp        )  || \
                                       ((IT_CONFIG) == TSC_IT_ThresholdMatches       )  || \
                                       ((IT_CONFIG) == TSC_IT_ThresholdMatches_WakeUp))  
/**
  * @}
  */ 

/** @defgroup TSC_IT_Flags_define 
 * @{
 */
#define  TSC_Flag_TimeSlot                   TSC_TKSR1_TKRCOV          //Time Slot
#define  TSC_Flag_ThresholdMatches           TSC_TKSR1_TKTHF	       //Threshold Matches         

#define  IS_TSC_IT_FLAGS(IT_FLAGS)    (((IT_FLAGS) == TSC_Flag_TimeSlot        )  || \
                                       ((IT_FLAGS) == TSC_Flag_ThresholdMatches)) 
/**
  * @}
  */ 

/** @defgroup TSC_Flags_define 
 * @{
 */
#define  TSC_Flag_Clk_RDY                   TSC_TKSR1_HCKRDY          //Clock source switch ready state
#define  TSC_Flag_ScanKey_Busy              TSC_TKSR1_TKBUSY          //ScanKey Busy        
#define  TSC_Flag_TimeOut_CF16Bit           TSC_TKSR1_TKCFOV          //Time Out CF 16BIT
#define  TSC_Flag_TimeOut_16BIT             TSC_TKSR1_TK16OV          //Time Out 16BIT

#define  IS_TSC_FLAGS(FLAGS)   (((FLAGS) == TSC_Flag_Clk_RDY        )  || \
                                ((FLAGS) == TSC_Flag_ScanKey_Busy   )  || \
                                ((FLAGS) == TSC_Flag_TimeOut_CF16Bit)  || \
                                ((FLAGS) == TSC_Flag_TimeOut_16BIT)) 
/**
  * @}
  */ 


/* Exported functions ------------------------------------------------------- */

/* Function used to set the TSC configuration to the default reset state *****/
void TSC_DeInit(void);

/* Initialization and Configuration functions *********************************/
void TSC_Init(TSC_InitTypeDef * TSC_InitStruct);
void TSC_StructInit(TSC_InitTypeDef *TSC_InitStruct);

/* TSC bit configuration functions **********************************************/
void TSC_TouchKeyConfig(uint32_t KeysBit, FunctionalState NewState);
void TSC_KeyThresholdConfig(uint32_t KeysBit, uint16_t ThresholdsValue);
void TSC_RefCAP_Config(uint32_t OptionBits);

void TSC_StartCmd(FunctionalState NewState);
void TSC_AutoCompareThresholdCmd(FunctionalState NewState);
void TSC_FilterCmd(FunctionalState NewState);
void TSC_OSC_Cmd(uint32_t OSC, FunctionalState NewState);

/* TSC configuration functions **********************************************/
void TSC_SetTimeSlotCount(uint8_t Value);
uint8_t TSC_GetTimeSlotCount(void);
void TSC_SetKeyRefCAP(uint8_t Channel, uint16_t capacitor);
uint16_t TSC_GetKeyRefCAP(uint8_t Channel);
void TSC_SetKeyThreshold(uint8_t Channel, uint16_t Threshold);
uint16_t TSC_GetKeyThreshold(uint8_t Channel);
uint16_t TSC_GetKeyCount(uint8_t Channel);
uint16_t TSC_GetCount(void);

/* Interrupts, flags management ***************************************/
void TSC_ITConfig(uint8_t TSC_IT, FunctionalState NewState);
ITStatus TSC_GetITStatus(uint32_t TSC_IT);
void TSC_ClearITPendingBit(uint32_t TSC_IT);
FlagStatus TSC_GetFlagStatus(uint32_t TSC_Flag);
void TSC_ClearFlagStatus(uint32_t TSC_Flag);

/* TSC KEY flags management ***************************************/
FlagStatus TSC_GetKeyFlag(uint32_t KeyBit);
void TSC_ClearKeyFlag(uint32_t KeyBit);

#ifdef __cplusplus
}
#endif

#endif /* __YS32T030_TSC_H */

/**
  * @}
  */

/**
  * @}
  */
